# neovim-gemini

A Neovim plugin for interacting with the Google AI API (formerly Gemini). Get AI-powered assistance directly within your Neovim editor.

## Requirements

* Neovim 0.8 or higher
* A Google AI API key (obtainable from [https://makersuite.google.com/app/apikey](https://makersuite.google.com/app/apikey))
* `curl` installed on your system
* Treesitter installed with the markdown parser (automatically installed during setup)

## Installation

Use your favorite Neovim package manager. Here's how to install with Lazy.nvim:

```lua
{
  "your_username/neovim-gemini",
  config = function()
    require("gemini").setup()
  end,
}
```

## Configuration

Set your API key using one of these methods:

1. Environment variable:
```bash
export GEMINI_API_KEY="your-api-key-here"
```

2. Neovim configuration:
```lua
-- In your init.lua
vim.g.gemini_api_key = "your-api-key-here"
```

## Usage

The plugin provides three ways to interact with Gemini:

1. Command Mode:
```vim
:Gemini What is SOLID in software engineering?
```

2. Simple Query (default):
- Press `<leader>gc` to open an input prompt (mnemonic: 'gemini chat')
- Type your query and press Enter

3. Context-Aware Query:
- Press `<leader>gs` to open an input prompt (mnemonic: 'gemini sync')
- This will send your current buffer's content as context along with your query
- Useful for code-related questions about the file you're working on

### Response Window

The AI response appears in a floating window. You can close it using:
- `q` key
- `<Esc>` key
- `<Enter>` key
- `:q` command

## Chat Features

The plugin now maintains a continuous chat session with Gemini:

- All conversations appear in a persistent chat window
- Chat history is maintained throughout the session
- Press `i` in the chat window to enter a new query
- Press `q` to close the chat window (history is preserved)
- Use `:GeminiClearChat` to clear the conversation history

### Chat Window Controls

While in the chat window:
- `i`: Enter a new query
- `q`: Close the window
- Normal mode scrolling commands work as expected
- Window automatically scrolls to show new messages

The chat window appears on the right side of your editor and preserves the entire conversation history until you explicitly clear it or restart Neovim.

## Features

- Floating window interface
- Non-blocking API calls
- Error handling and notifications
- Easy-to-use command and keymap interface
- Support for the latest Gemini 2.0 Flash model

## Troubleshooting

If you encounter issues:

1. Verify your API key is correctly set:
```lua
:lua print(vim.g.gemini_api_key)
```

2. Check if curl is installed:
```bash
curl --version
```

3. Ensure you have billing set up in your Google Cloud project

## License

This project is licensed under the ISC License. See the [LICENSE](LICENSE) file for details.

## Contributing

Contributions are welcome! Please feel free to submit a Pull Request.
